@@ -3,11 +3,12 @@
 #' Convert a table from crosstab format to TAF format.
 #'
 #' @param x a data frame in crosstab format.
+#' @param colname name for first column.
 #'
 #' @return A data frame in TAF format.
 #'
 #' @note
-#' TAF stores tables as data frames with a year column, as seen in stock
+#' TAF stores tables as data frames, usually with a year column as seen in stock
 #' assessment reports. The crosstab format can be more convenient for analysis
 #' and producing plots.
 #'
@@ -24,11 +25,12 @@
 #'
 #' @export
 
-xtab2taf <- function(x)
+xtab2taf <- function(x, colname="Year")
 {
   if(is.table(x))
     x <- unclass(x)  # handle xtabs() output
-  y <- data.frame(Year=simplify(row.names(x)), x, check.names=FALSE)
+  y <- data.frame(simplify(row.names(x)), x, check.names=FALSE)
+  names(y)[1] <- colname
   row.names(y) <- NULL
   y
 }
